import { fetchNumberOfSalesData } from "../../../pages/Graphs/barchart";

describe('fetchNumberOfSalesData', () => {
  it('should make a GET request to the correct API endpoint', async () => {
    // Mock the fetch API function
    const mockFetch = jest.fn();
    (window as any).fetch = mockFetch;

    // Define the expected parameters for the fetch call
    const expectedUrl = 'https://localhost/number_sales_by_date/day/2022-01-01/2022-01-03';
    const expectedOptions = {
      method: 'GET',
      headers: {
        'Content-Type': 'application/json',
      },
    };

    // Call the function being tested
    await fetchNumberOfSalesData(['day', '2022-01-01', '2022-01-03']);

    // Verify that fetch was called with the expected parameters
    expect(mockFetch).toHaveBeenCalledWith(expectedUrl, expectedOptions);
  });

  it('should return an array of data objects', async () => {
    // Mock the fetch API function
    const mockFetch = jest.fn();
    (window as any).fetch = mockFetch;

    // Define the response that the mock fetch function should return
    const mockResponse = {
      ok: true,
      json: () =>
        Promise.resolve([
          { date: '2022-01-01', numberSales: 12 },
          { date: '2022-01-02', numberSales: 15 },
          { date: '2022-01-03', numberSales: 18 },
        ]),
    };
    mockFetch.mockResolvedValue(mockResponse);

    // Call the function being tested
    const result = await fetchNumberOfSalesData(['day', '2022-01-01', '2022-01-03']);

    // Verify that the function returns the expected data
    expect(result).toEqual([
      { date: '2022-01-01', numberSales: 12 },
      { date: '2022-01-02', numberSales: 15 },
      { date: '2022-01-03', numberSales: 18 },
    ]);
  });
});
describe('Sum of number of sales', () => {
  it('should return the sum of number of sales', () => {
    const data = [
      { date: '2022-01-01', numberSales: 12 },
      { date: '2022-01-02', numberSales: 15 },
      { date: '2022-01-03', numberSales: 18 },
    ];
    const result = sumNumberOfSales(data);
    expect(result).toEqual(45);
  });
});
