import { fetchSalesByRegionData } from "../../../pages/Graphs/donutchart";

describe('fetchSalesByRegionData', () => {
    it('should make a GET request to the correct API endpoint', async () => {
        // Mock the fetch API function
        const mockFetch = jest.fn();
        (window as any).fetch = mockFetch;

        // Define the expected parameters for the fetch call
        const expectedUrl = 'https://localhost/sales_by_region';
        const expectedOptions = {
            method: 'GET',
            headers: {
                'Content-Type': 'application/json',
            },
        };

        // Call the function being tested
        await fetchSalesByRegionData("2021");

        // Verify that fetch was called with the expected parameters
        expect(mockFetch).toHaveBeenCalledWith(expectedUrl, expectedOptions);
    });

    it('should return an array of data objects', async () => {
        // Mock the fetch API function
        const mockFetch = jest.fn();
        (window as any).fetch = mockFetch;

        // Define the response that the mock fetch function should return
        const mockResponse = {
            ok: true,
            json: () =>
                Promise.resolve([
                    { region: 'Normandie', numberSales: 12 },
                    { region: 'Bretagne', numberSales: 15 },
                    { region: 'Occitanie', numberSales: 18 },
                ]),
        };
        mockFetch.mockResolvedValue(mockResponse);

        // Call the function being tested
        const result = await fetchSalesByRegionData("2021");

        // Verify that the function returns the expected data
        expect(result).toEqual([
            { region: 'Normandie', numberSales: 12 },
            { region: 'Bretagne', numberSales: 15 },
            { region: 'Occitanie', numberSales: 18 },
        ]);
    });
});
